@@ -352,16 +352,14 @@ show_package_details (package_info *pi, detail_kind kind,
 
   allow_updating ();
 
+  /* Build the dialog */
+  spd_with_details (c, false);
+
+  /* Show the data */
   if (pi->have_detail_kind != c->kind)
-    {
-      spd_with_details (c, false);
-      get_package_info (pi, false, spd_third_party_policy_check, c);
-    }
+    get_package_info (pi, false, spd_third_party_policy_check, c);
   else
-    {
-      /* Don't retrieve package info or details if already available */
-      spd_with_details (c, false);
-    }
+    spd_with_details (c, true);
 }
 
 static void
@@ -369,6 +367,11 @@ spd_third_party_policy_check (package_info *pi, void *data, bool unused)
 {
   spd_clos *c = (spd_clos *)data;
 
+  /* Exit if no valid data at this point */
+  if (current_spd_clos != data)
+    return;
+
+  /* Check current policy check */
   if (pi->third_party_policy != third_party_unknown)
     {
       /* Continue if this information was already known */
@@ -383,8 +386,9 @@ spd_third_party_policy_check (package_info *pi, void *data, bool unused)
 
 static void spd_third_party_policy_check_reply (package_info *pi, void *data)
 {
-  /* Just continue once the third party policy was checked */
-  spd_get_details (data);
+  /* Continue only if valid data is stored in 'data' */
+  if (current_spd_clos == data)
+    spd_get_details (data);
 }
 
 void
@@ -579,9 +583,24 @@ spd_update_common_page (void *data)
   gtk_widget_set_sensitive (GTK_WIDGET (table), TRUE);
 }
 
+static gint
+get_screen_width (void)
+{
+  GdkScreen *screen = NULL;
+  gint width = -1;
+
+  screen = gdk_screen_get_default ();
+  if (screen != NULL)
+    width = gdk_screen_get_width (screen);
+
+  return width;
+}
+
 static GtkWidget *
 make_small_text_label (const char *text)
 {
+  gint scn_width = get_screen_width ();
+
   GtkWidget *summary_table = gtk_table_new (1, 1, FALSE);
   gtk_table_set_col_spacings (GTK_TABLE (summary_table), 10);
   gtk_table_set_row_spacings (GTK_TABLE (summary_table), 0);
@@ -591,6 +610,11 @@ make_small_text_label (const char *text)
   gtk_label_set_line_wrap (GTK_LABEL (desc), TRUE);
   gtk_label_set_line_wrap_mode (GTK_LABEL (desc), PANGO_WRAP_WORD);
   gtk_label_set_ellipsize (GTK_LABEL (desc), PANGO_ELLIPSIZE_NONE);
+
+  /* Set GtkLabel width to 85% of screen width, to avoid weird wraps */
+  if (scn_width != -1)
+    gtk_widget_set_size_request (desc, scn_width * 0.85, -1);
+
   gtk_table_attach (GTK_TABLE (summary_table), desc, 0, 1, 0, 1,
 		    GtkAttachOptions (GTK_EXPAND | GTK_FILL), GTK_FILL,
 		    0, 0);
@@ -849,72 +873,67 @@ spd_with_details (void *data, bool filling_details)
       dialog = c->dialog;
       notebook = c->notebook;
       spd_nb_widgets = c->spd_nb_widgets;
-    }
 
-  if (c->showing_details)
-    {
-      is_ssu_pkg = is_pkg_ssu (pi);
-
-      /* Prevent the 'Updating' banner from being shown */
-      prevent_updating ();
-
-      if (is_ssu_pkg)
+      if (c->showing_details)
         {
-          spd_set_page_widget (c, SPD_COMMON_PAGE, spd_create_ssu_page (c));
+          is_ssu_pkg = is_pkg_ssu (pi);
+
+          /* Prevent the 'Updating' banner from being shown */
+          prevent_updating ();
+
+          if (is_ssu_pkg)
+            {
+              spd_set_page_widget (c, SPD_COMMON_PAGE, spd_create_ssu_page (c));
+            }
+          else
+            {
+              /* Update the main common tab */
+              spd_update_common_page (c);
+            }
+
+          /* Set the content of the rest of the notebook pages */
+
+          /* Check whether the 'description' tab should show up */
+          if (has_long_description (pi))
+            {
+              /* Now create and insert the "Description" tab in its place */
+              spd_nb_widgets[SPD_DESCRIPTION_PAGE] = spd_create_description_page (c);
+              gtk_notebook_insert_page (GTK_NOTEBOOK (notebook),
+                                        spd_nb_widgets[SPD_DESCRIPTION_PAGE],
+                                        gtk_label_new (_("ai_ti_details_noteb_description")),
+                                        SPD_DESCRIPTION_PAGE);
+            }
+
+          if (!is_ssu_pkg)
+            {
+              spd_set_page_widget (c, SPD_SUMMARY_PAGE,
+                                   spd_create_summary_page (c));
+
+              /* Update 'summary' tab label */
+              gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook),
+                                          spd_nb_widgets[SPD_SUMMARY_PAGE],
+                                          gtk_label_new (spd_get_summary_label (c)));
+            }
+          else
+            {
+              // we don't need this tab
+              gtk_notebook_remove_page (GTK_NOTEBOOK (notebook), SPD_SUMMARY_PAGE);
+            }
+
+          if (pi->dependencies && !is_ssu_pkg)
+            {
+              spd_nb_widgets[SPD_DEPS_PAGE] = spd_create_deps_page (c);
+              gtk_notebook_append_page (GTK_NOTEBOOK (notebook),
+                                        spd_nb_widgets[SPD_DEPS_PAGE],
+                                        gtk_label_new (_("ai_ti_details_noteb_dependencies")));
+            }
         }
-      else
-        {
-          /* Update the main common tab */
-          spd_update_common_page (c);
-        }
-
-      /* Set the content of the rest of the notebook pages */
-
-      /* Check whether the 'description' tab should show up */
-      if (has_long_description (pi))
-        {
-          /* Now create and insert the "Description" tab in its place */
-          spd_nb_widgets[SPD_DESCRIPTION_PAGE] = gtk_vbox_new (TRUE, 0);
-
-          gtk_notebook_insert_page (GTK_NOTEBOOK (notebook),
-                                    spd_nb_widgets[SPD_DESCRIPTION_PAGE],
-                                    gtk_label_new (_("ai_ti_details_noteb_description")),
-                                    SPD_DESCRIPTION_PAGE);
-
-          /* Fill the tab */
-          spd_set_page_widget (c, SPD_DESCRIPTION_PAGE,
-                               spd_create_description_page (c));
-        }
-
-      if (!is_ssu_pkg)
-        {
-          spd_set_page_widget (c, SPD_SUMMARY_PAGE,
-                               spd_create_summary_page (c));
-
-          /* Update 'summary' tab label */
-          gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook),
-                                      spd_nb_widgets[SPD_SUMMARY_PAGE],
-                                      gtk_label_new (spd_get_summary_label (c)));
-        }
-      else
-        {
-          // we don't need this tab
-          gtk_notebook_remove_page (GTK_NOTEBOOK (notebook), SPD_SUMMARY_PAGE);
-        }
-
-      if (pi->dependencies && !is_ssu_pkg)
-	{
-	  spd_nb_widgets[SPD_DEPS_PAGE] = spd_create_deps_page (c);
-	  gtk_notebook_append_page (GTK_NOTEBOOK (notebook),
-				    spd_nb_widgets[SPD_DEPS_PAGE],
-				    gtk_label_new (_("ai_ti_details_noteb_dependencies")));
-	}
     }
 
   g_signal_connect (dialog, "response",
 		    G_CALLBACK (spd_response), c);
 
-  gtk_widget_set_size_request (dialog, 600, 320);
+  gtk_widget_set_size_request (dialog, -1, 320);
   gtk_widget_show_all (dialog);
 
   if (c->show_problems && c->showing_details && !is_ssu_pkg)
